@@ -319,11 +319,14 @@ static void accept_new(void)
 	    if (entry) {
 		vcc->entry = entry;
 		Q_INSERT_HEAD(entry->vccs,vcc);
-		if (entry->state == as_valid)
-		    if (set_ip(vcc->fd,entry->ip) < 0)
+		if (entry->state == as_valid) {
+		    if (set_ip(vcc->fd,entry->ip) < 0) {
 			diag(COMPONENT,DIAG_ERROR,"set_ip: %s",
 			  strerror(errno));
-		set_sndbuf(vcc);
+			disconnect_vcc(vcc);
+		    }
+		    else set_sndbuf(vcc);
+		}
 		return;
 	    }
 	}
@@ -414,7 +417,6 @@ int set_ip(int fd,int ip)
     if (ioctl(fd,ATMARP_SETENTRY,ip) >= 0) return 0;
     error = -errno;
     diag(COMPONENT,DIAG_ERROR,"ioctl ATMARP_SETENTRY: %s",strerror(errno));
-    (void) do_close(fd);
     return error;
 }
 
