@@ -35,6 +35,7 @@ int main(int argc,const char **argv)
 static void usage(const char *name)
 {
     fprintf(stderr,"usage: %s [ [ -f ] esi ] [ itf ]\n",name);
+    fprintf(stderr,"%6s %s -V\n","",name);
     exit(1);
 }
 
@@ -50,11 +51,14 @@ int main(int argc,char **argv)
     op = ATM_SETESI;
     memset(&req,0,sizeof(req));
     esi = NULL;
-    while ((c = getopt(argc,argv,"f")) != EOF)
+    while ((c = getopt(argc,argv,"fV")) != EOF)
 	switch (c) {
 	    case 'f':
 		op = ATM_SETESIF;
 		break;
+	    case 'V':
+		printf("%s\n",VERSION);
+		return 0;
 	    default:
 		usage(*argv);
 	}
